.. :changelog:

Changelog
---------

2.0.0 (2017-01-25)
---------------------

* Case insensitive matching. (Gokul Soumya)
* Add an accessor function for fuzzy find. (Amjith)
* Support integer inputs. (Matheus)
